# battery-bus: body: li-ion

- previous design(s): [v1](./li-ion-v1.md).

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121307.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121307.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121319.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121319.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121331.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121331.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121339.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121339.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121344.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121344.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121349.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121349.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121357.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/li-ion/v2/20251211_121357.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/20251210_204219.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/20251210_204219.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/battery-bus/20251210_204306.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/battery-bus/20251210_204306.jpg?raw=true) |
